[][src]Trait substrate_primitives::crypto::Ss58Codec

pub trait Ss58Codec: Sized {
    fn from_ss58check(s: &str) -> Result<Self, PublicError>;
fn to_ss58check(&self) -> String; fn from_string(s: &str) -> Result<Self, PublicError> { ... } }

Key that can be encoded to/from SS58.

Required methods

fn from_ss58check(s: &str) -> Result<Self, PublicError>

Some if the string is a properly encoded SS58Check address.

fn to_ss58check(&self) -> String

Return the ss58-check string for this key.

Loading content...

Provided methods

fn from_string(s: &str) -> Result<Self, PublicError>

Some if the string is a properly encoded SS58Check address, optionally with a derivation path following.

Loading content...

Implementors

impl<T: AsMut<[u8]> + AsRef<[u8]> + Default + Derive> Ss58Codec for T[src]

Loading content...