[][src]Struct substrate_primitives::ed25519::Signature

pub struct Signature(pub [u8; 64]);

A signature (a 512-bit value).

Methods

impl Signature[src]

pub fn from_raw(data: [u8; 64]) -> Signature[src]

A new instance from the given 64-byte data.

NOTE: No checking goes on to ensure this is a real signature. Only use it if you are certain that the array actually is a signature. GIGO!

pub fn from_slice(data: &[u8]) -> Self[src]

A new instance from the given slice that should be 64 bytes long.

NOTE: No checking goes on to ensure this is a real signature. Only use it if you are certain that the array actually is a signature. GIGO!

pub fn from_h512(v: H512) -> Signature[src]

A new instance from an H512.

NOTE: No checking goes on to ensure this is a real signature. Only use it if you are certain that the array actually is a signature. GIGO!