[−][src]Module substrate_primitives::crypto
Cryptographic utilities.
Enums
| DeriveJunction | A since derivation junction description. It is the single parameter used when creating
a new secret key from an existing secret key and, in the case of |
| Infallible | The infallible type. |
| PublicError | An error type for SS58 decoding. |
| SecretStringError | An error with the interpretation of a secret. |
Constants
| DEV_ADDRESS | The address of the associated root phrase for our publicly known keys. |
| DEV_PHRASE | The root phrase for our publicly known keys. |
| JUNCTION_ID_LEN | The length of the junction identifier. Note that this is also referred to as the
|
Traits
| Derive | Derivable key trait. |
| Pair | Trait suitable for typical cryptographic PKI key pair type. |
| Ss58Codec | Key that can be encoded to/from SS58. |
| UncheckedFrom | Similar to |
| UncheckedInto | The counterpart to |