[−][src]Trait substrate_primitives::crypto::Ss58Codec
Key that can be encoded to/from SS58.
Required methods
fn from_ss58check(s: &str) -> Result<Self, PublicError>
Some if the string is a properly encoded SS58Check address.
fn to_ss58check(&self) -> String
Return the ss58-check string for this key.
Provided methods
fn from_string(s: &str) -> Result<Self, PublicError>
Some if the string is a properly encoded SS58Check address, optionally with a derivation path following.